@@ -6,6 +6,8 @@ from pymongo import MongoClient
 import copy
 from bson.objectid import ObjectId
 
+import copy
+
 
 def create_connection_to_mongo(db_name, collection_name, url):
     client = MongoClient(url)
@@ -39,7 +41,7 @@ class MongoBaseModel:
         create_connection_to_mongo(self.db_name, self.collection_name, self.url).insert_one(data)
 
     def validate_data(self):
-        for field in self.data:
+        for field in copy.deepcopy(self.data):
             if field not in self.fields:
                 del self.data[field]
 
